@@ -9,9 +9,10 @@ App::Codit::Plugins::SearchReplace - plugin for App::Codit
 use strict;
 use warnings;
 use vars qw( $VERSION );
-$VERSION = 0.11;
+$VERSION = 0.14;
 
 use base qw( Tk::AppWindow::BaseClasses::Plugin );
+use Tk;
 require Tk::LabFrame;
 require Tk::ITree;
 
@@ -26,12 +27,19 @@ Search and replace across multiple files.
 
 =head1 DETAILS
 
-This plugin allows you to do a search and replace across multiple files or just one file. 
-After filling out the search and replace fields you first click Find. 
+This plugin allows you to do a search and replace across multiple or just one file.
 
-The list box will fill with the search results. When you click Replace the first item in 
-the list is replaced and then removed from the list. 
-You can skip replaces by pressing Skip. Clear deletes all search results.
+After filling out the search and replace fields you first click Find.
+The list box will fill with the search results.
+
+When you click Replace the first item in the list is replaced and then removed from the list.
+
+You can skip replaces by pressing Skip.
+
+When searching with a regular expression you can include the captures you make with () in
+the replace string with ‘$1’, ‘$2’, etcetera.
+
+Clear removes all search results.
 
 =cut
 
@@ -51,7 +59,7 @@ sub new {
 	my $searchmode = 'Search in current document';
 
 	$self->{CASE} = \$casesensitive;
-	$self->{FRESH} = {};
+	$self->{CURRENT} = undef;
 	$self->{LASTRESULTS} = [];
 	$self->{MODE} = \$searchmode;
 	$self->{OFFSET} = {};
@@ -70,23 +78,23 @@ sub new {
 
 	my $sf = $sa->Frame->pack(-expand => 1, -fill => 'x');
 	$sf->Label(
-	   -text => 'Search',
-	   -width => 7,
-	   -anchor => 'e',
+		-text => 'Search',
+		-width => 7,
+		-anchor => 'e',
 	)->pack(@padding, -side => 'left');
 	my $se = $sf->Entry(
-	   -textvariable => \$searchterm,
+		-textvariable => \$searchterm,
 	)->pack(@padding, -side => 'left', -expand => 1, -fill => 'x');
 	$se->bind('<Return>', [$self, 'Find']);
 
 	my $rf = $sa->Frame->pack(-expand => 1, -fill => 'x');
 	$rf->Label(
-	   -text => 'Replace',
-	   -width => 7,
-	   -anchor => 'e',
+		-text => 'Replace',
+		-width => 7,
+		-anchor => 'e',
 	)->pack(@padding, -side => 'left');
 	$rf->Entry(
-	   -textvariable => \$replaceterm,
+		-textvariable => \$replaceterm,
 	)->pack(@padding, -side => 'left', -expand => 1, -fill => 'x');
 
 	my $sb = $page->LabFrame(
@@ -96,22 +104,22 @@ sub new {
 	)->pack(@padding, -fill => 'x');
 
 	$sb->Checkbutton(
-	   -variable => \$useregex,
-	   -text => 'Regular expression',
+		-variable => \$useregex,
+		-text => 'Regular expression',
 		-onvalue => '-regexp',
 		-offvalue => '-exact',
-	   -anchor => 'w',
+		-anchor => 'w',
 	)->pack(@padding, -fill => 'x');
 	$sb->Checkbutton(
-	   -variable => \$casesensitive,
+		-variable => \$casesensitive,
 		-onvalue => '-case',
 		-offvalue => '-nocase',
-	   -text => 'Case sensitive',
-	   -anchor => 'w',
+		-text => 'Case sensitive',
+		-anchor => 'w',
 	)->pack(@padding, -fill => 'x');
 	my $mb = $sb->Menubutton(
 #		-relief => 'raised',
-	   -anchor => 'w',
+		-anchor => 'w',
 		-textvariable => \$searchmode,
 	)->pack(@padding, -fill => 'x');
 	my @menu = ();
@@ -130,58 +138,70 @@ sub new {
 		-relief => 'groove',
 		-borderwidth => 2,
 	)->pack(@padding, -fill => 'x');
+	$sc->gridColumnconfigure(0, -weight => 2);
+	$sc->gridColumnconfigure(1, -weight => 2);
 	$sc->Button(
 		-command => ['Find', $self],
 		-text => 'Find',
-	)->pack(@padding, -fill => 'x');
-	$sc->Button(
-		-command => ['Replace', $self],
-		-text => 'Replace',
-	)->pack(@padding, -fill => 'x');
-	$sc->Button(
-		-command => ['Skip', $self],
-		-text => 'Skip',
-	)->pack(@padding, -fill => 'x');
+		-width => 8,
+	)->grid(@padding, -column => 0, -row => 0, -sticky => 'ew');
 	$sc->Button(
 		-command => ['Clear', $self],
 		-text => 'Clear',
-	)->pack(@padding, -fill => 'x');
+		-width => 8,
+	)->grid(@padding, -column => 1, -row => 0, -sticky => 'ew');
+	$sc->Button(
+		-command => ['Replace', $self],
+		-text => 'Replace',
+		-width => 8,
+	)->grid(@padding, -column => 0, -row => 1, -sticky => 'ew');
+	$sc->Button(
+		-command => ['Skip', $self],
+		-text => 'Skip',
+		-width => 8,
+	)->grid(@padding, -column => 1, -row => 1, -sticky => 'ew');
 
 
 	my $tf = $page->Frame(
 		-relief => 'groove',
 		-borderwidth => 2,
 	)->pack(@padding, -expand => 1, -fill => 'both');
-	my $bf = $tf->Frame->pack(-fill => 'x');
-	$bf->Button(
+	$tf->gridColumnconfigure(0, -weight => 2);
+	$tf->gridColumnconfigure(1, -weight => 2);
+	$tf->gridRowconfigure(1, -weight => 2);
+	$tf->Button(
 		-text => 'Previous',
 		-command => ['BrowsePrevious', $self],
-	)->pack(@padding, -side => 'left', -expand => 1, -fill => 'x');
-	$bf->Button(
-		-text => '  Next  ',
+		-width => 8,
+	)->grid(@padding, -column => 0, -row => 0, -sticky => 'ew');
+	$tf->Button(
+		-text => 'Next',
 		-command => ['BrowseNext', $self],
-	)->pack(@padding, -side => 'left', -expand => 1, -fill => 'x');
+		-width => 8,
+	)->grid(@padding, -column => 1, -row => 0, -sticky => 'ew');
 	my $results = $tf->Scrolled('ITree',
 		-height => 4,
 		-browsecmd => ['Select', $self],
 		-scrollbars => 'osoe',
 		-separator => '@',
-	)->pack(@padding, -expand => 1, -fill => 'both');
+	)->grid(@padding, -column => 0, -columnspan => 2, -row => 1, -sticky => 'nsew');
 	$results->autosetmode;
 	$self->{RESULTSLIST} = $results;
+	
+	$self->cmdHookAfter('doc_select', 'ShowResults', $self);
 
 	return $self;
 }
 
 sub BrowseNext {
 	my $self = shift;
-	my $list = $self->{RESULTSLIST};
+	my $list = $self->list;
 	my ($sel) = $list->infoSelection;
 
 	#select the first hit if no selection is set
 	unless (defined $sel) {
 		$sel = $self->SelectFirst;
-		return 
+		return
 	}
 	return unless defined $sel;
 
@@ -189,7 +209,7 @@ sub BrowseNext {
 	my $last = $self->GetLast;
 	if ($self->IsSelected($last)) {
 		$sel = $self->SelectFirst;
-		return 
+		return
 	}
 
 	my ($name, $index) = split(/@/, $sel);
@@ -201,7 +221,7 @@ sub BrowseNext {
 			my @d = $list->infoChildren($nname);
 			if (@d) {
 				$self->Select($d[0]);
-				return 
+				return
 			}
 		} else {
 			$self->Select($next);
@@ -211,13 +231,13 @@ sub BrowseNext {
 
 sub BrowsePrevious {
 	my $self = shift;
-	my $list = $self->{RESULTSLIST};
+	my $list = $self->list;
 	my ($sel) = $list->infoSelection;
 
 	#select the last hit if no selection is set
 	unless (defined $sel) {
 		$self->SelectLast;
-		return 
+		return
 	}
 	return unless defined $sel;
 
@@ -225,7 +245,7 @@ sub BrowsePrevious {
 	my $first = $self->GetFirst;
 	if ($self->IsSelected($first)) {
 		$self->SelectLast;
-		return 
+		return
 	}
 	my ($name, $index) = split(/@/, $sel);
 	if (defined $index) {
@@ -243,21 +263,21 @@ sub BrowsePrevious {
 
 sub Clear {
 	my $self = shift;
-	my $list = $self->{RESULTSLIST};
+	my $list = $self->list;
 	my @c = $list->infoChildren('');
+	$self->Current(undef);
 	$self->{LASTRESULTS} = \@c;
 	$list->deleteAll;
 	$self->{OFFSET} = {};
 	$self->repl(0);
 	$self->skipped(0);
+	$self->ShowResults;
 }
 
-sub ClearFresh {
-	my ($self, $name) = @_;
-	if (exists $self->{FRESH}->{$name}) {
-		$self->DocWidget($name)->unselectAll;
-		delete $self->{FRESH}->{$name};
-	}
+sub Current {
+	my $self = shift;
+	$self->{CURRENT} = shift if @_;
+	return $self->{CURRENT}
 }
 
 sub DocSelected {
@@ -275,6 +295,7 @@ sub DocWidget {
 sub Find {
 	my $self = shift;
 	my $search = $self->{SEARCH};
+	$self->Current(undef);
 	if ($$search eq '') {
 		$self->popMessage("Please enter a search phrase", 'dialog-warning', 32);
 		return
@@ -296,6 +317,7 @@ sub Find {
 	} elsif ($$mode eq $srchres) {
 		$self->FindInResults;
 	}
+	$self->ShowResults;
 }
 
 sub FindInDoc {
@@ -305,76 +327,91 @@ sub FindInDoc {
 	my $search = $self->{SEARCH};
 	my $case = $self->{CASE};
 	my $regex = $self->{REGEX};
-	my $results = $self->{RESULTSLIST};
+	my $results = $self->list;
+	my $srch;
+	if ($$regex eq '-exact') {
+		$srch = quotemeta($$search)
+	} else {
+		eval "qr/$$search/";
+		my $error = $@;
+		if ($error ne '') {
+			$error =~ s/\n//;
+			$self->logError($error);
+			return
+		}
+		$srch = $$search;
+	}
+	if ($$case eq '-case') {
+		$srch = qr/$srch/
+	} else {
+		$srch = qr/$srch/i
+	}
+	my @hits = ();
 	if (($mdi->docExists($name)) and (not $mdi->deferredExists($name))) {
 		my $widg = $mdi->docGet($name)->CWidg;
-		my $srch = $$search;
-		$srch = quotemeta($srch) if $$regex eq 'exact';
-		$widg->FindAll($$regex, $$case, $srch);
-		my @ranges = $widg->tagRanges('sel');
-		if (@ranges) {
-			$results->add($name,
-				-text => $self->abbreviate($name, 30),
-				-itemtype => 'imagetext',
-				-image =>  $self->getArt('text-x-plain')
-			); 
-			$results->autosetmode;
+		my $last = $widg->linenumber('end - 1c');
+		my $end = $widg->index('end - 1c');
+		my $count = 0;
+		for (1 .. $last) {
+			my $linenum = $_;
+			my $linestart = "$linenum.0";
+	
+			my $lineend = $widg->index("$linestart lineend + 1c");
+			$lineend = $end if $widg->compare($end,'<',$lineend);
+			my $line = $widg->get($linestart, $lineend);
+			push @hits, $self->FindInLine($line, $srch, $linenum);
 		}
-
-		while (@ranges) {
-			my $begin = shift @ranges;
-			my $end = shift @ranges;
-			my $line = $widg->get("$begin linestart", "$begin lineend - 1c");
-			$line =~ s/^\s+//; #removing leading spaces and tabs
-			$results->add($name . '@' . $begin,
-				-text => "$begin - $line",
-				-data => $begin,
-			);
-			$results->autosetmode;
-		}
-		$self->{FRESH}->{$name} = 1;
 	} else {
-		my @hits = ();
 		if (open IFILE, "<", $name) {
 			my $linenum = 1;
-			my $srch = $$search;
-			$srch = quotemeta($srch) if $$regex eq 'exact';
 			while (<IFILE>) {
 				my $line = $_;
-				$line =~ s/\n$//; #remove trailing newline
-				my $copy = $line;
-				$line =~ s/^\s+//; #remove leading spaces
-				my $offset = 0;
-				while ($copy =~ /($srch)/g) {
-					my $pos = pos($copy);
-					$pos = $pos - length($1);
-					push @hits, ["$linenum.$pos", $line];
-				}
+				push @hits, $self->FindInLine($line, $srch, $linenum);
 				$linenum ++;
 			}
 			close IFILE;
 		}
-		if (@hits) {
-			$results->add($name,
-				-text => $self->abbreviate($name, 30),
-				-itemtype => 'imagetext',
-				-image =>  $self->getArt('text-x-plain')
-			); 
-		}
-		while (@hits) {
-			my $hit = shift @hits;
-			my $begin = $hit->[0];
-			my $line = $hit->[1];
-			$results->add($name . '@' . $begin,
-				-text => "$begin - $line",
-				-data => $begin,
-			);
-			$results->autosetmode;
-		}
+	}
+	if (@hits) {
+		$results->add($name,
+			-text => $self->abbreviate($name, 30),
+			-itemtype => 'imagetext',
+			-image =>  $self->getArt('text-x-plain')
+		);
+	}
+	while (@hits) {
+		my $hit = shift @hits;
+		my $begin = $hit->[0];
+		my $line = $hit->[2];
+		$results->add($name . '@' . $begin,
+			-text => "$begin - $line",
+			-data => $hit,
+		);
+		$results->autosetmode;
 	}
 	$self->update;
 }
 
+sub FindInLine {
+	my ($self, $line, $search, $linenum) = @_;
+	$line =~ s/\n$//; #remove trailing newline
+	my $copy = $line;
+	$line =~ s/^\s+//; #remove leading spaces
+	my $offset = 0;
+	my @hits = ();
+	while ($copy =~ /($search)/g) {
+		my $end = pos($copy);
+		my $begin = $end - length($1);
+		my @cap = ();
+		if ($#- > 1) {
+			no strict 'refs';
+			@cap = map {$$_} 2 .. $#-;
+		}
+		push @hits, ["$linenum.$begin", "$linenum.$end", $line, \@cap];
+	}
+	return @hits;
+}
+
 sub FindInProject {
 	my $self = shift;
 	my $git = $self->extGet('Plugins')->plugGet('Git');
@@ -406,7 +443,7 @@ sub FinishedCheck {
 	my $self = shift;
 	my $cur = $self->GetCurrent;
 	unless (defined $cur) {
-		$self->{RESULTSLIST}->selectionClear;
+		$self->list->selectionClear;
 		my $num = $self->{REPLACES};
 		$self->Report(1);
 		return 1
@@ -416,7 +453,7 @@ sub FinishedCheck {
 
 sub GetCurrent {
 	my $self = shift;
-	my $list = $self->{RESULTSLIST};
+	my $list = $self->list;
 	my @c = $list->infoChildren('');
 	my $mdi = $self->extGet('CoditMDI');
 
@@ -427,10 +464,10 @@ sub GetCurrent {
 		my $cur = $hits[$offset];
 		if (defined $cur) {
 			$mdi->docSelect($name);
-			if(exists $self->{FRESH}->{$name}) {
-				$self->DocWidget($name)->unselectAll;
-				delete $self->{FRESH}->{$name};
-			}
+#			if(exists $self->{FRESH}->{$name}) {
+#				$self->DocWidget($name)->unselectAll;
+#				delete $self->{FRESH}->{$name};
+#			}
 			return $cur
 		}
 	}
@@ -457,7 +494,7 @@ sub GetLast {
 sub GetList {
 	my ($self, $name, $flag) = @_;
 	$flag = 0 unless defined $flag;
-	my $list = $self->{RESULTSLIST};
+	my $list = $self->list;
 	unless (defined $name) {
 		my @d = $list->infoChildren('');
 		if ($flag) {
@@ -467,6 +504,7 @@ sub GetList {
 			return $list->infoChildren($d[0]);
 		}
 	} else {
+		return () unless $list->infoExists($name);
 		return $list->infoChildren($name);
 	}
 }
@@ -480,12 +518,14 @@ sub GoCurrent {
 
 sub IsSelected {
 	my ($self, $entry) = @_;
-	my $list = $self->{RESULTSLIST};
+	my $list = $self->list;
 	my ($sel) = $list->infoSelection;
 	return 0 unless defined $sel;
 	return $sel eq $entry
 }
 
+sub list { return $_[0]->{RESULTSLIST} }
+
 sub OffsetGet {
 	my ($self, $name) = @_;
 	return $self->{OFFSET}->{$name} if exists $self->{OFFSET}->{$name};
@@ -509,24 +549,30 @@ sub Replace {
 	my $cur = $self->GetCurrent;
 	unless (defined $cur) {
 		$self->logWarning('Nothing to replace');
-		return 
+		return
 	}
 	my ($name, $index) = split(/@/, $cur);
 	my $widg = $self->DocWidget($name);
-	my $list = $self->{RESULTSLIST};
-	if ($widg->selectionExists) {
-		my $replace = $self->{REPLACE};
-		$widg->ReplaceSelectionsWith($$replace);
+	if (defined $self->Current) {
+		my $list = $self->list;
+		my ($begin, $end, $dummy, $captures) = $list->infoData($cur);
+		my $r = $self->{REPLACE};
+		my $replace = $$r;
+		if (@$captures) {
+			my $num = 1;
+			for (@$captures) {
+				my $cap = $_;
+				$replace =~ s/\$$num/$cap/g;
+				$num ++
+			}
+		}
+		$widg->replace($begin, $end, $replace);
 		$list->deleteEntry($cur);
-
 		$self->repl($self->repl + 1);
-		$self->Report;
 		my @h = $list->infoChildren($name);
 		$list->deleteEntry($name) unless @h;
-		$self->GoCurrent unless $self->FinishedCheck;
-	} else {
-		$self->GoCurrent unless $self->FinishedCheck;
 	}
+	$self->GoCurrent unless $self->FinishedCheck;
 }
 
 sub repl {
@@ -548,43 +594,25 @@ sub Report {
 sub Select {
 	my ($self, $entry) = @_;
 	my ($name, $index) = split(/@/, $entry);
-	my $search = $self->{SEARCH};
-	my $mdi = $self->extGet('CoditMDI');
-	my $list = $self->{RESULTSLIST};
+	my $mdi = $self->mdi;
+	my $list = $self->list;
+
 	$list->selectionClear;
 	$list->anchorClear;
 	$list->selectionSet($entry);
 	return if $entry eq $name;
+	$self->Current($entry);
+	my ($begin, $end) = $list->infoData($entry);
+
 	$self->cmdExecute('doc_open', $name) unless ($mdi->docExists($name));
 	$mdi->docSelect($name);
 	my $widg = $mdi->docGet($name)->CWidg;
+
 	$widg->unselectAll;
-	$widg->goTo($index);
-	my $len = length($$search);
-	$widg->tagAdd('sel', $index, "$index + $len c");
+	$widg->goTo($begin);
 	$widg->focus;
 }
 
-sub skipped {
-	my $self = shift;
-	$self->{SKIPPED} = shift if @_;
-	return $self->{SKIPPED}
-}
-
-sub Skip {
-	my $self = shift;
-	my $cur = $self->GetCurrent;
-	unless (defined $cur) {
-		$self->logWarning('Nothing to skip');
-		return 
-	}
-	my ($name, $index) = split(/@/, $cur);
-	$self->OffsetInc($name);
-	$self->skipped($self->skipped + 1);
-	$self->Report;
-	$self->GoCurrent unless $self->FinishedCheck;
-}
-
 sub SelectFirst {
 	my $self = shift;
 	my $first = $self->GetFirst;
@@ -597,12 +625,51 @@ sub SelectLast {
 	$self->Select($last) if defined $last
 }
 
+sub ShowResults {
+	my $self = shift;
+	my $mdi = $self->mdi;
+	my $name = $mdi->docSelected;
+	return @_ unless defined $name;
+	my $widg = $mdi->docWidget;
+	my $list = $self->list;
+	my @hits = $self->GetList($name);
+	$widg->FindClear;
+	for (@hits) {
+		my $data = $list->infoData($_);
+		my ($begin, $end) = @$data;
+		$widg->tagAdd('Find', $begin, $end);
+	}
+	$self->after(500, sub { $widg->tagRaise('Find') }); #make sure syntax highlighting does not overwrite the tags
+	$self->after(3000, sub { $widg->tagRaise('Find') if Exists $widg }); #make sure syntax highlighting does not overwrite the tags
+	return @_;
+}
+
+sub Skip {
+	my $self = shift;
+	my $cur = $self->GetCurrent;
+	unless (defined $cur) {
+		$self->logWarning('Nothing to skip');
+		return
+	}
+	my ($name, $index) = split(/@/, $cur);
+	if (defined $self->Current) {
+		$self->OffsetInc($name);
+		$self->skipped($self->skipped + 1);
+		$self->Report;
+	}
+	$self->GoCurrent unless $self->FinishedCheck;
+}
+
+sub skipped {
+	my $self = shift;
+	$self->{SKIPPED} = shift if @_;
+	return $self->{SKIPPED}
+}
+
 sub Unload {
 	my $self = shift;
 	$self->ToolRightPageRemove('SearchReplace');
-#	$self->extGet('ToolPanel')->deletePage('SearchReplace');
-	my $id = $self->{REFRESHID};
-	$self->afterCancel($id) if defined $id;
+	$self->cmdUnhookAfter('doc_select', 'ShowResults', $self);
 	return $self->SUPER::Unload
 }
 
